@@ -53,13 +53,17 @@ our $I18N = {
     'lastUpdated' => '1231712723',
     'message' => '[[METHOD]] wordt vervangen door de naam van de standaard methode van deze functionaliteit. De standaard naam voor deze methode is view (bekijken)'
   },
+  'profile_user_id' => {
+    'lastUpdated' => '1346180031',
+    'message' => 'De userId van de gebruiker wiens account wordt bekeken. '
+  },
   'root_url' => {
     'lastUpdated' => '1231712745',
     'message' => 'Het URL om terug te gaan naar het hoofdscherm van de Account.'
   },
   'user_full_name' => {
-    'lastUpdated' => '1231712759',
-    'message' => 'De volledige naam van de gebruiker.'
+    'lastUpdated' => '1346180059',
+    'message' => 'De volledige naam van de gebruiker wiens account wordt bekeken.'
   },
   'user_member_since' => {
     'lastUpdated' => '1231712817',
